/* ###################################################################
**     Filename    : main.c
**     Project     : I2C-SHT11-K64-trail
**     Processor   : MK64FN1M0VLL12
**     Version     : Driver 01.01
**     Compiler    : GNU C Compiler
**     Date/Time   : 2015-02-20, 19:46, # CodeGen: 0
**     Abstract    :
**         Main module.
**         This module contains user's application code.
**     Settings    :
**     Contents    :
**         No public methods
**
** ###################################################################*/
/*!
** @file main.c
** @version 01.01
** @brief
**         Main module.
**         This module contains user's application code.
*/         
/*!
**  @addtogroup main_module main module documentation
**  @{
*/         
/* MODULE main */


/* Including needed modules to compile this module/procedure */
#include "Cpu.h"
#include "Events.h"
#include "Pins1.h"
#include "WAIT1.h"
#include "SDA.h"
#include "WAIT1.h"
#include "CsIO1.h"
#include "IO1.h"
#include "SCL.h"
/* Including shared modules, which are used for whole project */
#include "PE_Types.h"
#include "PE_Error.h"
#include "PE_Const.h"
#include "IO_Map.h"
#include "PDD_Includes.h"
#include "Init_Config.h"
/* User includes (#include below this line is not maintained by Processor Expert) */


//- Module constants, see SHT1x datasheet for more information ------------------------------------
const float C1=-4.0;              // for 12 Bit
const float C2=+0.0405;           // for 12 Bit
const float C3=-0.0000028;        // for 12 Bit
const float T1=+0.01;             // for 14 Bit
const float T2=+0.00008;          // for 14 Bit

// SHT1x definitions
#define noACK 0
#define ACK   1
                            //adr  command  r/w
#define STATUS_REG_W 0x06   //000   0011    0
#define STATUS_REG_R 0x07   //000   0011    1
#define MEASURE_TEMP 0x03   //000   0001    1
#define MEASURE_HUMI 0x05   //000   0010    1
#define RESET        0x1e   //000   1111    0

//- Module variables -------------------------------------------------------------------------------
unsigned char ucSens_Error;

int iSHT_Temp;
int iSHT_Humi;


float temp;
float rel_hum;

char Temp_str[16];
char Humi_str[16];

void Read_SHT11(float *fT, float *fRH);
void s_transstart();

//float *fT, *fRH;



// I2C using bit banging
// I2C SDA-> PTC3-->J1-16
//  I2C SCL-> PTC2-->J1-14


LDD_TUserData *SDA_Ptr, *SCL_Ptr;
unsigned char Dir=0, Val;
//Dir             - Direction to set. Possible values:
//**                           <false> - Input
//**                           <true> - Output

//Dir=TRUE;

/*lint -save  -e970 Disable MISRA rule (6.3) checking. */

//SDA_dir = 1;	->	SDA_SetDir(SDA_Ptr, 1); set as output mode
//SDA_dir = 0; 	->	SDA_SetDir(SDA_Ptr, 0);  set as input mode

// SDA_pin = 1;  ->  SDA_SetVal(SDA_Ptr);
//  SDA_pin = 0;	-> SDA_ClrVal(SDA_Ptr);

// SCL_pin = 0;  -->   SCL_ClrVal(SCL_Ptr);
// SCL_pin = 1; -> 	SCL_SetVal(SCL_Ptr);

//SDA_pin == 1	-> SDA_GetVal(SDA_Ptr) == 1
//SDA_pin == 0	-> SDA_GetVal(SDA_Ptr) == 0


//  Delay_uS(1);   WAIT1_Waitus(1);		//
//  Delay_uS(3);   WAIT1_Waitus(3);		//


// Delay_mS(1);   WAIT1_Waitms(1);
// Delay_mS(3);   WAIT1_Waitms(3);


void s_transstart()
{
  //Initial state
	SDA_SetDir(SDA_Ptr, 0);	//SDA_SetDir(SDA_Ptr, 1); //set as output// SDA_dir = 1;                            //release DATA-line
	SDA_SetVal(SDA_Ptr);  // giving high to the bit// SDA_pin = 1;
	SCL_ClrVal(SCL_Ptr);  // giving 0 to the bit//SCL_pin = 0;                           // SCL Low

  WAIT1_Waitus(1);	//Delay_uS(1);
  SCL_SetVal(SCL_Ptr);  // giving high to the bit // SCL_pin = 1;
  WAIT1_Waitus(1);//Delay_uS(1);

  SDA_SetDir(SDA_Ptr, 1); //set as output //SDA_dir = 0;        // define SDA as output
  SDA_ClrVal(SDA_Ptr);   //SDA_pin = 0;                           // SDA low
  WAIT1_Waitus(1);     //Delay_uS(1);

  SCL_ClrVal(SCL_Ptr); //SCL_pin = 0;
  WAIT1_Waitus(3);      // Delay_uS(3);
  SCL_SetVal(SCL_Ptr);   //SCL_pin = 1;

  WAIT1_Waitus(1); //Delay_uS(1);
  SDA_SetDir(SDA_Ptr, 0);   //SDA_dir = 1;
  WAIT1_Waitus(1);    //Delay_uS(1);
  SCL_ClrVal(SCL_Ptr); //SCL_pin = 0;
}



unsigned char s_read_byte(unsigned char ack)
{
  unsigned char i=0x80;
  unsigned char val=0;

  //Initial state
  SDA_SetDir(SDA_Ptr, 1);                            //release DATA-line
  SDA_SetVal(SDA_Ptr);
  SCL_ClrVal(SCL_Ptr);                           // SCL Low

  while(i)                //shift bit for masking
  {
    SCL_SetVal(SCL_Ptr);          //clk for SENSI-BUS
    SDA_SetDir(SDA_Ptr, 0);	//input mode  added
    WAIT1_Waitus(1);     // Delay_uS(1);
    if (SDA_GetVal(SDA_Ptr) == 1)
    {
      val=(val | i);      //read bit
    }
    SCL_ClrVal(SCL_Ptr);
    WAIT1_Waitus(1);	//Delay_uS(1);
    i=(i>>1);
  }

  SDA_SetDir(SDA_Ptr, 1);

  if (ack)
  {
    //in case of "ack==1" pull down DATA-Line
    SDA_ClrVal(SDA_Ptr);
  }
  else
  {
    SDA_SetVal(SDA_Ptr);
  }

  SCL_SetVal(SCL_Ptr);                //clk #9 for ack
  WAIT1_Waitus(3);	//Delay_uS(3);
  SCL_ClrVal(SCL_Ptr);
  WAIT1_Waitus(1);	// Delay_uS(1);

  SDA_SetDir(SDA_Ptr, 1);                           //release DATA-line
  SDA_SetVal(SDA_Ptr);


  //printf("Value value T: %3.1f degC\n", val);//bheem

  return (val);
}



unsigned char s_write_byte(unsigned char value)
{
  unsigned char i=0x80;
  unsigned char error=0;

  SDA_SetDir(SDA_Ptr, 1);

  while(i)
  { //shift bit for masking
    if (i & value)
    {
      SDA_SetVal(SDA_Ptr);    //masking value with i , write to SENSI-BUS
    }
    else
    {
      SDA_ClrVal(SDA_Ptr);
    }

    SCL_SetVal(SCL_Ptr);  //clk for SENSI-BUS
    WAIT1_Waitus(3);	//Delay_uS(3);
    SCL_ClrVal(SCL_Ptr);
    WAIT1_Waitus(3);	//Delay_uS(3);
    i=(i>>1);
  }

  SDA_SetDir(SDA_Ptr, 1);                           //release DATA-line
  SDA_SetVal(SDA_Ptr);

  SCL_SetVal(SCL_Ptr);                           //clk #9 for ack
  WAIT1_Waitus(3);		//Delay_uS(3);
  SDA_SetDir(SDA_Ptr, 0); //added input mode

  if (SDA_GetVal(SDA_Ptr) == 1)  error = 1; //check ack (DATA will be pulled down by SHT11)
  WAIT1_Waitus(1);		//Delay_uS(1);
  SCL_ClrVal(SCL_Ptr);

  return(error); //error=1 in case of no acknowledge
}



unsigned char s_measure(unsigned int *p_value, unsigned char mode)
{
  unsigned char i=0;
  unsigned char msb,lsb;
  unsigned char checksum;

  *p_value=0;
  s_transstart(); //transmission start

  if(mode)
  {
    mode = MEASURE_HUMI;
  }
  else
  {
    mode = MEASURE_TEMP;
  }

  if (s_write_byte(mode)) return(1);
  // normal delays: temp i=70, humi i=20

  SDA_SetDir(SDA_Ptr, 0);	// SDA_dir = 1;

  while(i<240)
  {
    WAIT1_Waitms(1);
    WAIT1_Waitms(1);
    WAIT1_Waitms(1);
    if (SDA_GetVal(SDA_Ptr) == 0)
    {
      i=0;
      break;
    }
    i++;
  }

  // or timeout
  if(i) return(2);

  msb=s_read_byte(ACK); //read the first byte (MSB)
  lsb=s_read_byte(ACK); //read the second byte (LSB)
  checksum=s_read_byte(noACK);                //read checksum (8-bit)

  *p_value=(msb<<8)|(lsb);

  //printf("Temperature value T: %3.1f degC\n", p_value);//bheem


  return(0);
}



float calc_sth11_temp(unsigned int t)
{
  float t_out;
  t_out =  t*0.01 - 40;

  return t_out;
}


float calc_sth11_humi(unsigned int h, int t)
{
  float rh_lin;                             // rh_lin:  Humidity linear
  float rh_true;                            // rh_true: Temperature compensated humidity
  float t_C;                                // t_C   :  Temperature [C]

  t_C=t*0.01 - 40;                          //calc. temperature from ticks to [C]
  rh_lin=C3*h*h + C2*h + C1;                //calc. humidity from ticks to [%RH]
  rh_true=(t_C-25)*(T1+T2*h)+rh_lin;        //calc. temperature compensated humidity

  // now calc. Temperature compensated humidity [%RH]
  // the correct formula is:
  // rh_true=(t/10-25)*(0.01+0.00008*(sensor_val))+rh;
  // sensor_val ~= rh*30
  // we use:
  // rh_true=(t/10-25) * 1/8;

  if(rh_true>100)rh_true=100;               //cut if the value is outside of
  if(rh_true<0.1)rh_true=0.1;               //the physical possible range

  return rh_true;
}


void Read_SHT11(float *fT, float *fRH)
{
  unsigned int t;
  unsigned int h;

  float value=0;
  ucSens_Error = 0;

  ucSens_Error = s_measure(&t, 0);
  *fT = calc_sth11_temp(t);
  ucSens_Error = s_measure(&h, 1);
  *fRH = calc_sth11_humi(h, t);

/*
  ucSens_Error = s_measure(&t, 0);
    iSHT_Temp = (int)(calc_sth11_temp(t) * 10);

    ucSens_Error = s_measure(&h, 1);
    iSHT_Humi = (int)(calc_sth11_humi(h, t) * 10);

    value = (float)iSHT_Temp;
    *fT = value / 10;
    value = (float)iSHT_Humi;
    *fRH = value / 10;
*/

}


char s_read_statusreg(unsigned char *p_value)
{
  unsigned char checksum = 0;

  s_transstart();                             //transmission start
  if(s_write_byte(STATUS_REG_R)) return 1;    //send command to sensor
  *p_value=s_read_byte(ACK);                  //read status register (8-bit)
  checksum=s_read_byte(noACK);                //read checksum (8-bit)

  return 0;
}



char s_write_statusreg(unsigned char value)
{
  s_transstart();                             //transmission start
  if(s_write_byte(STATUS_REG_W)) return 1;    //send command to sensor
  if(s_write_byte(value)) return 1;           //send value of status register

  return 0;
}


void s_connectionreset()
{
  unsigned char i;

  //Initial state
  SDA_SetDir(SDA_Ptr, 1);                            //release DATA-line
  SDA_SetVal(SDA_Ptr);
  SCL_ClrVal(SCL_Ptr);                           // SCL Low

  for(i=0; i<9; i++)                     //9 SCK cycles
  {
    SCL_SetVal(SCL_Ptr);
    WAIT1_Waitus(3);
    SCL_ClrVal(SCL_Ptr);
    WAIT1_Waitus(3);
  }

  s_transstart();                        //transmission start
}



unsigned char s_softreset(void)
{
  s_connectionreset();                         //reset communication
                                               //send RESET-command to sensor
  return (s_write_byte(RESET));                //return=1 in case of no response form the sensor
}




int main(void)
/*lint -restore Enable MISRA rule (6.3) checking. */
{
  /* Write your local variable definition here */

  /*** Processor Expert internal initialization. DON'T REMOVE THIS CODE!!! ***/
  PE_low_level_init();
  /*** End of Processor Expert internal initialization.                    ***/

  /* Write your code here */
  /* For example: for(;;) { } */

  unsigned int *p_value1, *p_value2;
  SDA_Init(SDA_Ptr);
  SCL_Init(SCL_Ptr);


while(1){

	//s_transstart();

//	s_measure(p_value1, 1);
//	printf("Temperature value T: %d degC\n", p_value1);
//
//	s_measure(p_value2, 0);
//	printf("Humidity value T: %f degC\n", p_value2);

	Read_SHT11(&temp, &rel_hum);
	WAIT1_Waitms(250);
	 printf(" Temperature value T: %f %% degC\t", temp);
	 printf(" Humidity value RH: %f pct\r\n", rel_hum);

	// printf("inside main Temperature value T: %f degC\n", temp);
	//	 printf("indise main  Humidity value RH: %f pct\n", rel_hum);

}

  /*** Don't write any code pass this line, or it will be deleted during code generation. ***/
  /*** RTOS startup code. Macro PEX_RTOS_START is defined by the RTOS component. DON'T MODIFY THIS CODE!!! ***/
  #ifdef PEX_RTOS_START
    PEX_RTOS_START();                  /* Startup of the selected RTOS. Macro is defined by the RTOS component. */
  #endif
  /*** End of RTOS startup code.  ***/
  /*** Processor Expert end of main routine. DON'T MODIFY THIS CODE!!! ***/
  for(;;){}
  /*** Processor Expert end of main routine. DON'T WRITE CODE BELOW!!! ***/
} /*** End of main routine. DO NOT MODIFY THIS TEXT!!! ***/

/* END main */
/*!
** @}
*/
/*
** ###################################################################
**
**     This file was created by Processor Expert 10.4 [05.11]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
